@@ -119,6 +119,12 @@ class I3d(XMLComponent):
         tree = self.get_tree(splines_i3d_path)
 
         roads_polylines = self.get_infolayer_data(Parameters.TEXTURES, Parameters.ROADS_POLYLINES)
+
+        if self.map.i3d_settings.field_splines:
+            fields_polygons = self.get_infolayer_data(Parameters.TEXTURES, Parameters.FIELDS)
+            if isinstance(roads_polylines, list) and isinstance(fields_polygons, list):
+                roads_polylines.extend(fields_polygons)
+
         if not roads_polylines:
             self.logger.warning("Roads polylines data not found in textures info layer.")
             return
@@ -152,8 +158,14 @@ class I3d(XMLComponent):
 
         node_id = SPLINES_NODE_ID_STARTING_VALUE
         for road_id, road_info in enumerate(roads_polylines, start=1):
-            points = road_info.get("points")
-            tags = road_info.get("tags")
+            if isinstance(road_info, dict):
+                points = road_info.get("points")
+                tags = road_info.get("tags")
+                is_field = False
+            else:
+                points = road_info
+                tags = "field"
+                is_field = True
 
             try:
                 fitted_road = self.fit_object_into_bounds(
@@ -168,11 +180,11 @@ class I3d(XMLComponent):
                 continue
 
             fitted_road = self.interpolate_points(
-                fitted_road, num_points=self.map.spline_settings.spline_density
+                fitted_road, num_points=self.map.i3d_settings.spline_density
             )
             fitted_roads = [(fitted_road, "original")]
 
-            if self.map.spline_settings.add_reversed_splines:
+            if self.map.i3d_settings.add_reversed_splines:
                 reversed_fitted_road = fitted_road[::-1]
                 fitted_roads.append((reversed_fitted_road, "reversed"))
 
@@ -208,20 +220,23 @@ class I3d(XMLComponent):
 
                 shapes_node.append(nurbs_curve_node)
 
-                user_attribute_node = self.get_user_attribute_node(
-                    node_id,
-                    attributes=[
-                        ("maxSpeedScale", "integer", "1"),
-                        ("speedLimit", "integer", "100"),
-                    ],
-                )
+                if not is_field:
+                    user_attribute_node = self.get_user_attribute_node(
+                        node_id,
+                        attributes=[
+                            ("maxSpeedScale", "integer", "1"),
+                            ("speedLimit", "integer", "100"),
+                        ],
+                    )
 
-                user_attributes_node.append(user_attribute_node)
+                    user_attributes_node.append(user_attribute_node)
                 node_id += 1
 
         tree.write(splines_i3d_path)  # type: ignore
         self.logger.debug("Splines I3D file saved to: %s.", splines_i3d_path)
 
+        self.assets.splines = splines_i3d_path
+
     def _add_fields(self) -> None:
         """Adds fields to the map I3D file."""
         tree = self.get_tree()
@@ -285,6 +300,8 @@ class I3d(XMLComponent):
 
         self.save_tree(tree)
 
+        self.assets.fields = self.xml_path
+
     def _get_field_xml_entry(
         self, field_id: int, field_ccs: list[tuple[int, int]], node_id: int
     ) -> tuple[ET.Element, int] | tuple[None, int]:
@@ -559,6 +576,8 @@ class I3d(XMLComponent):
             scene_node.append(trees_node)
             self.save_tree(tree)
 
+        self.assets.forests = self.xml_path
+
     @staticmethod
     def randomize_coordinates(
         coordinates: tuple[int, int], density: int, shift_percent: int
